MatlabElementType

Enum MatlabElementType 

#[repr(u8)]
pub enum MatlabElementType {
Show 75 variants Whitespace = 0, Newline = 1, Comment = 2, BlockComment = 3, Identifier = 4, Number = 5, String = 6, Character = 7, Function = 8, End = 9, If = 10, Else = 11, Elseif = 12, While = 13, For = 14, Break = 15, Continue = 16, Return = 17, Switch = 18, Case = 19, Otherwise = 20, Try = 21, Catch = 22, Global = 23, Persistent = 24, Classdef = 25, Properties = 26, Methods = 27, Events = 28, Plus = 29, Minus = 30, Times = 31, Divide = 32, Power = 33, LeftDivide = 34, DotTimes = 35, DotDivide = 36, DotPower = 37, DotLeftDivide = 38, Equal = 39, NotEqual = 40, Less = 41, Greater = 42, LessEqual = 43, GreaterEqual = 44, And = 45, Or = 46, Not = 47, AndAnd = 48, OrOr = 49, Assign = 50, LeftParen = 51, RightParen = 52, LeftBracket = 53, RightBracket = 54, LeftBrace = 55, RightBrace = 56, Semicolon = 57, Comma = 58, Dot = 59, Colon = 60, Question = 61, At = 62, Transpose = 63, DotTranspose = 64, Operator = 65, Delimiter = 66, Error = 67, Script = 68, FunctionDef = 69, ClassDef = 70, Block = 71, Expression = 72, Statement = 73, Eof = 74,
}
Element types for the Matlab language.

Variants



Whitespace = 0

Whitespace.



Newline = 1

Newline.



Comment = 2

Line comment.



BlockComment = 3

Block comment.



Identifier = 4

Identifier.



Number = 5

Number literal.



String = 6

String literal.



Character = 7

Character literal.



Function = 8

function keyword.



End = 9

end keyword.



If = 10

if keyword.



Else = 11

else keyword.



Elseif = 12

elseif keyword.



While = 13

while keyword.



For = 14

for keyword.



Break = 15

break keyword.



Continue = 16

continue keyword.



Return = 17

return keyword.



Switch = 18

switch keyword.



Case = 19

case keyword.



Otherwise = 20

otherwise keyword.



Try = 21

try keyword.



Catch = 22

catch keyword.



Global = 23

global keyword.



Persistent = 24

persistent keyword.



Classdef = 25

classdef keyword.



Properties = 26

properties keyword.



Methods = 27

methods keyword.



Events = 28

events keyword.



Plus = 29

+ operator.



Minus = 30

- operator.



Times = 31

* operator.



Divide = 32

/ operator.



Power = 33

^ operator.



LeftDivide = 34

\ operator.



DotTimes = 35

.* operator.



DotDivide = 36

./ operator.



DotPower = 37

.^ operator.



DotLeftDivide = 38

.\ operator.



Equal = 39

== operator.



NotEqual = 40

~= operator.



Less = 41

< operator.



Greater = 42

> operator.



LessEqual = 43

<= operator.



GreaterEqual = 44

>= operator.



And = 45

& operator.



Or = 46

| operator.



Not = 47

~ operator.



AndAnd = 48

&& operator.



OrOr = 49

|| operator.



Assign = 50

= operator.



LeftParen = 51

( delimiter.



RightParen = 52

) delimiter.



LeftBracket = 53

[ delimiter.



RightBracket = 54

] delimiter.



LeftBrace = 55

{ delimiter.



RightBrace = 56

} delimiter.



Semicolon = 57

; delimiter.



Comma = 58

, delimiter.



Dot = 59

. delimiter.



Colon = 60

: delimiter.



Question = 61

? delimiter.



At = 62

@ delimiter.



Transpose = 63

' operator.



DotTranspose = 64

.' operator.



Operator = 65

General operator.



Delimiter = 66

General delimiter.



Error = 67

Error element.



Script = 68

Script element.



FunctionDef = 69

Function definition element.



ClassDef = 70

Class definition element.



Block = 71

Block element.



Expression = 72

Expression element.



Statement = 73

Statement element.



Eof = 74

End of stream.

Implementations

Source

impl MatlabElementType

pub fn is_token(&self) -> bool

Returns true if the element type is a token.

pub fn is_element(&self) -> bool

Returns true if the element type is an element.